@@ -1,6 +1,6 @@
 package Role::HasPayload;
-BEGIN {
-  $Role::HasPayload::VERSION = '0.005';
+{
+  $Role::HasPayload::VERSION = '0.006';
 }
 use Moose::Role;
 # ABSTRACT: something that carries a payload
@@ -9,8 +9,10 @@ use Moose::Role;
 requires 'payload';
 
 no Moose::Role;
+1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -19,7 +21,7 @@ Role::HasPayload - something that carries a payload
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 OVERVIEW
 
@@ -45,10 +47,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
